<?php

/**
 * @file
 * This class extends the context_condition by implementing a condition that
 * matches on a term's vocabulary in a taxonomy listing. 
 */
class cep_taxonomy_vocabulary_context_condition extends context_condition {

  function condition_values() {
    $values = array();
    if (module_exists('taxonomy')) {
      foreach (taxonomy_get_vocabularies() as $vocab) {
         $values[$vocab->vid] = $vocab->name;
      }
    }
    return $values;
  }

  function condition_form($context) {
    $form = parent::condition_form($context);
    $form['#type'] = 'select';
    $form['#size'] = 12;
    $form['#multiple'] = TRUE;
    $form['#options'] = $this->condition_values();
    return $form;
  }

  /**
   * Execute.
   */
  function execute() {
    $args = arg();
    if ($this->condition_used() && $args[0] == 'taxonomy' && $args[1] == 'term' && is_numeric($args[2])) {
      foreach (context_enabled_contexts() as $context) {
        if ($selected_vocabs = $this->fetch_from_context($context, 'values')) {
          $term = taxonomy_get_term($args[2]);
          if ($term && isset($selected_vocabs[$term->vid])) {
            $this->condition_met($context, $term->vid);
          }
        }
      }
    }
  }
}
